@@ -16,7 +16,10 @@
 package LinuxDocTools::fmt_latex2e;
 use strict;
 
-use LinuxDocTools::Utils qw(ldt_log);
+use LinuxDocTools::Utils qw(
+  ldt_log
+  ldt_which
+  );
 use LinuxDocTools::CharEnts;
 use LinuxDocTools::Vars;
 use LinuxDocTools::Lang;
@@ -255,6 +258,10 @@ sub latex2e_fine_tune_options {
     } elsif ($global->{language} eq "ko") {
       # for Korean users
       $latex2e->{latex} = "hlatexp";
+    } elsif ( $global->{language} =~ /^zh/ ) {
+      die "$msgheader: Chinese requires utf-8. Aborting ...\n"
+	unless ( $global->{'charset'} eq "utf-8" );
+      $latex2e->{latex} = "xelatex";
     } else {
       $latex2e->{latex} = "latex";
     }
@@ -307,6 +314,10 @@ sub latex2e_fine_tune_options {
   ldt_log "    format: $global->{format}, charset: $global->{charset}, lang: $global->{language}";
   ldt_log "    latex: $latex2e->{latex}, dvips: $latex2e->{dvips}, output: $latex2e->{output}, verbosity: $latex2e->{verbosity}";
 
+  ldt_log "  Check if \"$latex2e->{latex}\" is available. ldt_which will fail otherwise";
+  ldt_log "    ldt_which($latex2e->{latex}): " . ldt_which($latex2e->{latex})
+    unless ( $latex2e->{output} eq "tex" );
+
   return $latex2e;
 };
 
@@ -437,8 +448,6 @@ $latex2e->{postASP} = sub
   #  Set the correct \documentclass and packages options.
   # --------------------------------------------------------------------
   {
-    my $langlit = ISO2English ($global->{language});
-    $langlit = ($langlit eq 'english') ? "" : "$langlit";
     my $hlatexopt = "";
 
     # Getting document class prefix
@@ -454,19 +463,24 @@ $latex2e->{postASP} = sub
     # Getting class options
     my $classoptions = $global->{papersize} . 'paper';
 
-    # Getting babel options
-    my $babeloptions = $langlit || "english";
-    if ( ($global->{charset} eq "nippon")
-	 ||
-	 ($global->{charset} eq "euc-kr")
-	 ||
-	 ($global->{language} eq "ja" && $global->{charset} eq "utf-8")
-      ) {
-      $babeloptions = '';
+    # Getting and setting latex language
+    my $latex_language = ISO2English ($global->{language});
+    my $use_babel      = 1;
+    if (( not defined $global->{language} )
+	||
+	( $global->{language} =~ /^zh/  )
+	||
+	($global->{charset} eq "nippon")
+	||
+	($global->{charset} eq "euc-kr")
+	||
+	($global->{language} eq "ja" && $global->{charset} eq "utf-8")
+      ){
+      $use_babel = '';
     }
     ldt_log "  ${msgheader} general info:";
     ldt_log "    format: $global->{format}, charset: $global->{charset}, lang: $global->{language}";
-    ldt_log "    latex: $latex2e->{latex}, classprefix: $classprefix, babeloptions: $babeloptions";
+    ldt_log "    latex: $latex2e->{latex}, classprefix: $classprefix, latex_language: $latex_language, use_babel: $use_babel";
 
     open ($OUTFILE, "> $tmplatexnam.tex")
       or die "fmt_latex2e::postASP: Could not open \"$tmplatexnam.tex\" for write.\n";
@@ -511,10 +525,12 @@ $latex2e->{postASP} = sub
 	    my $dtd = $global->{"dtd"};
 	    s/\@LINUXDOC_DTD\@/$dtd/;
 	  }
-	  # Set correct babel options
-	  elsif (/^\\usepackage\[\@BABELOPTIONS\@\]\{babel\}/) {
-	    if ( $babeloptions ) {
-	      s/\@BABELOPTIONS\@/$babeloptions/;
+	  # Set correct language package and babel options if needed
+	  elsif (/^\@\@LANG_PACKAGE\@\@/) {
+	    if ( $global->{'language'} eq "zh_CN" ){
+	      s/\@\@LANG_PACKAGE\@\@/\\usepackage\[UTF8\]\{ctex\}/;
+	    } elsif ( $use_babel ) {
+	      s/\@\@LANG_PACKAGE\@\@/\\usepackage\[$latex_language\]\{babel\}/;
 	    } else {
 	      s/^/%%/;
 	    }
