@@ -9,19 +9,27 @@
 
 package LinuxDocTools::Lang;
 
+require 5.0004;
+
 use strict;
-use vars qw($VERSION @ISA @EXPORT @Languages);
 
 use LinuxDocTools::Data::Strings_SBCS;
 use LinuxDocTools::Data::Strings_UTF8;
-
-require 5.0004;
-use Exporter;
+use LinuxDocTools::Utils qw(ldt_log);
 use LinuxDocTools::Vars;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
-@ISA     = qw(Exporter);
-@EXPORT  = qw(Any2ISO ISO2Native ISO2English Xlat);
+use base qw(Exporter);
+
+# List all unconditionally exported symbols here.
+our @EXPORT = qw(Any2ISO ISO2Native ISO2English Xlat);
+
+# List all conditionally exported symbols here.
+# our @EXPORT_OK = qw();
+
+# Import :all to get everything.
+# our %EXPORT_TAGS = (all => [@EXPORT_OK]);
+
+# -------------------------------------------------------
 
 =head1 NAME
 
@@ -50,7 +58,7 @@ language as C<deutsch>, as C<german> or as C<de>.
 
 =cut
 
-@Languages = qw(
+our @Languages = qw(
   en english english
   de deutsch german
   nl nederlands dutch
@@ -67,6 +75,7 @@ language as C<deutsch>, as C<german> or as C<de>.
   pl polski polish
   ko korean korean
   fi suomi finnish
+  zh_CN chinese-simplified chinese-simplified
 );
 
 
@@ -148,16 +157,18 @@ has all available translations.
 
 sub Xlat {
   my ($txt) = @_;
-  my $string;
+  my $string = $txt;
+  my $translations = ( $global->{charset} eq "utf-8" )
+    ? $LinuxDocTools::Data::Strings_UTF8::translations
+    : $LinuxDocTools::Data::Strings_SBCS::translations;
 
-  if ( $global->{language} eq "en" ){
-    $string = $txt;
-  } elsif ($global->{charset} eq "utf-8") {
-    $string = $LinuxDocTools::Data::Strings_UTF8::translations->{$txt}{$global->{language}};
-  } else {
-    $string = $LinuxDocTools::Data::Strings_SBCS::translations->{$txt}{$global->{language}};
+  if ( defined $global->{language}
+       && defined $translations->{$txt}{$global->{language}}
+       && $global->{language} ne "en" ){
+    $string = $translations->{$txt}{$global->{language}};
   }
-  # print STDERR "Xlang: $txt, $global->{language}, $global->{charset}, \"$string\"\n";
+  ldt_log "LinuxDocTools::Lang.pm::Xlang: in_string: \"$txt\", language: \"$global->{language}\", charset: \"$global->{charset}\", out_string: \"$string\"";
+
   return $string;
 };
 
